<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>
	
	<!-- Translations -->
	<xsl:param name="sReportTitle">Student Assignments History</xsl:param>
	<xsl:param name="sHistoryHeading">History</xsl:param>
	<xsl:param name="sCounselHeading">Counsel</xsl:param>
	<xsl:param name="sWeekHeading">Week</xsl:param>
	<xsl:param name="sNotAssigned">Not assigned:</xsl:param>
	<xsl:param name="sNoStudentHistoryFound">No student history found.</xsl:param>
	
	<!-- Variables -->
	<xsl:variable name="HistDB" select="document('AssignHistory.XML')"/>
	<xsl:variable name="PubDB" select="document('MSA_PublisherDatabase.XML')"/>

	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
				<title>
					<xsl:value-of select="$sReportTitle"/>
				</title>
			</head>
			<xsl:choose>
				<xsl:when test="$CSSFile1 !=''">
					<style type="text/css">
						<xsl:value-of select="$CSSFile1"/>
					</style>
				</xsl:when>
				<xsl:otherwise>
					<link rel="stylesheet" type="text/css" href="Custom--S-140--Student-History Counsel.css"/>
				</xsl:otherwise>
			</xsl:choose>
			<body>
				<h1>Student Assignment History — Counsel</h1>
				<xsl:for-each select="$PubDB/msa:PublisherDatabase/msa:Publishers/msa:Publisher/msa:Name">
					<!-- Keep each students information in it's own container. This prevents splitting over page breaks when printing.-->
					<div class="container">
						<h2>
							<xsl:value-of select="."/>
						</h2>
						<h3>
							<xsl:value-of select="$sHistoryHeading"/>
						</h3>
						<xsl:variable name="strName" select="."/>
						<xsl:choose>
							<!-- Only display a table if the student has history data -->
							<xsl:when test="count($HistDB//AssignmentHistory/*/StudentItems/Item/Name[(@Brochure = 'th' or not(@Brochure)) and @Counsel and . = $strName]) != 0">
								<table class="counsel">
									<colgroup>
										<col width="50%"/>
										<col width="50%"/>
									</colgroup>
									<!-- Column Headings-->
									<thead>
										<tr>
											<th class="counsel">
												<xsl:value-of select="$sCounselHeading"/>
											</th>
											<th class="counsel">
												<xsl:value-of select="$sWeekHeading"/>
											</th>
										</tr>
									</thead>

									<!-- Test for the Counsel attribute so that we exclude Assistant items -->
									<!-- Limit counsel data to the student -->
									<xsl:for-each select="$HistDB//AssignmentHistory/*/StudentItems/Item/Name[(@Brochure = 'th' or not(@Brochure)) and @Counsel and . = $strName]">
										<!-- Sort by counsel number (ascending) -->
										<xsl:sort select="@Counsel" data-type="number"/>

										<!-- Then sort by date (ascending) -->
										<xsl:sort select="local-name(../../..)"/>

										<tr>
											<!-- Counsel -->
											<td class="counsel">
												<xsl:value-of select="@Counsel"/>
											</td>
											<!-- Date DD/MM/YYYY -->
											<td class="counsel">
												<xsl:variable name="strWeek" select="local-name(../../..)"/>
												<xsl:value-of select="substring($strWeek, 8, 2)"/>
												<xsl:text>/</xsl:text>
												<xsl:value-of select="substring($strWeek, 6, 2)"/>
												<xsl:text>/</xsl:text>
												<xsl:value-of select="substring($strWeek, 2, 4)"/>
											</td>
										</tr>

									</xsl:for-each>
								</table>
								
								<!-- Indicate which lessons the students has not been assigned -->
								<xsl:variable name="missing-items">
									<xsl:call-template name="list-missing-items">
										<xsl:with-param name="items" select ="$HistDB//AssignmentHistory/*/StudentItems/Item/Name[@Counsel and .=$strName]"/>
									</xsl:call-template>
								</xsl:variable>
								
								<p class="not-assigned">
									<xsl:value-of select="$sNotAssigned"/>
									<xsl:text> </xsl:text>
									<br/>
									<xsl:value-of select="translate(normalize-space($missing-items), ' ', ',')" />
								</p>
							</xsl:when>
							<xsl:otherwise>
								<p>
									<xsl:value-of select="$sNoStudentHistoryFound"/>
								</p>
							</xsl:otherwise>
						</xsl:choose>
					</div>
				</xsl:for-each>
			</body>
		</html>
	</xsl:template>

	<xsl:template name="list-missing-items">
		<xsl:param name="items"/>
		<xsl:param name="max" select="20"/>
		<xsl:if test="$max > 1">
			<xsl:call-template name="list-missing-items">
				<xsl:with-param name="items" select="$items"/>
				<xsl:with-param name="max" select="$max - 1"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:if test="not ($max=$items/@Counsel)">
			<xsl:value-of select="$max" />
			<xsl:text> </xsl:text>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>

